# -*- coding:utf-8 -*-
from nbconvert.preprocessors.execute import ExecutePreprocessor
from nbconvert.exporters.exporter import Exporter
from traitlets import List


class TigerPreprocessor(ExecutePreprocessor):

    def preprocess(self, nb, resources=None, km=None):
        print(nb)
        print(resources)
        print(km)
        super(TigerPreprocessor, self).preprocess(nb, resources, km)

    def preprocess_cell(self, cell, resources, index):
        super(TigerPreprocessor, self).preprocess_cell(cell, resources, index)


print("Attach tiger_executor.TigerPreprocessor")
_preprocess = Exporter.default_preprocessors.default_args[0] + ['tiger_executor.TigerPreprocessor'] # noqa E501
Exporter.default_preprocessors = List(list(_preprocess)).tag(config=True) # noqa E501



# -*- coding:utf-8 -*-
from tiger_notebook.component_drill.drill.base_drill import BaseDrill
from tiger_notebook.component_drill.drill.python_single_drill import PythonSingleDrill
from tiger_notebook.component_drill.drill.aistudio_argo_drill import AistudioArgoDrill
from tiger_notebook.component_drill.drill.sample_train_drill import SampleTrainDrill



# -*- coding:utf-8 -*-
from tiger_notebook.component_drill.util.log_util import get_logger

logger = get_logger("__name__")


class BaseDrill(object):

    code_name = None
    engine_type = None

    def get_main_file_path(self):
        return "main.py"

    def get(self, node_instance_id=None, local_dir=None):
        logger.info('get yet not implement')

    def update(self, node_instance_id=None, local_dir=None):
        logger.info('update yet not implement')



# -*- coding:utf-8 -*-
from tiger_notebook.component_drill.drill.base_drill import BaseDrill
from tiger_notebook.component_drill.util.log_util import get_logger

logger = get_logger("__name__")


class SampleTrainDrill(BaseDrill):
    code_name = 'train'
    engine_type = 3

    def get_main_file_path(self):
        return "main.py"

    def get(self, node_instance_id=None, local_dir=None):
        logger.info(node_instance_id)
        logger.info(local_dir)
        logger.info('SampleTrainDrill get ~')

    def update(self, node_instance_id=None, local_dir=None):
        logger.info(node_instance_id)
        logger.info(local_dir)
        logger.info('SampleTrainDrill update ~')



# -*- coding:utf-8 -*-
from tiger_notebook.component_drill.drill.base_drill import BaseDrill
from tiger_notebook.component_drill import drill
import inspect
import argparse
parser = argparse.ArgumentParser()
parser.add_argument('-a', help='get/update', default='get', required=True)
parser.add_argument('-c', help='code_name')
parser.add_argument('-n', help='node_instance_id', required=True)
parser.add_argument('-d', help='local_dir', required=True)
parser.add_argument('-o', help='output')
args = parser.parse_args()


def get_engine_type(node_instance_id):
    return node_instance_id


def main():
    print(args.a)
    print(args.c)
    print(args.n)
    print(args.d)
    print(args.o)
    code_name = args.c
    node_instance_id = args.n
    local_dir = args.d
    # 获取drill
    drill_ = BaseDrill()

    code_names = {
        obj.code_name: obj for name, obj in inspect.getmembers(drill) if inspect.isclass(obj) and obj.code_name
    }
    engine_types = {
        obj.engine_type: obj for name, obj in inspect.getmembers(drill) if inspect.isclass(obj) and obj.engine_type
    }
    if code_name and code_name in code_names:
        drill_ = code_names.get(code_name)()
    else:
        engine_type = get_engine_type(node_instance_id=node_instance_id)
        print('haha %s' % engine_type)
        if engine_type and int(engine_type) in engine_types:
            print(engine_types.get(int(engine_type))())
            drill_ = engine_types.get(int(engine_type))()
    print(code_names)
    print(engine_types)

    getattr(drill_, args.a)(node_instance_id=node_instance_id, local_dir=local_dir)


if __name__ == "__main__":
    main()



# -*- coding:utf-8 -*-
import os
from setuptools import find_packages
from setuptools import setup

install_requires = []
exclude_file_patterns = [".git"]
version = {}
with open(os.path.join("tiger_notebook/_version.py")) as fp:
    exec(fp.read(), version)
setup(
    name="tiger_notebook",
    version=version["__version__"],
    description="tiger notebook",
    url="",
    author="tiger",
    install_requires=install_requires,
    packages=find_packages(where=".", exclude=exclude_file_patterns),
    package_data={"": ["*.so"]},
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "tiger_component_drill=tiger_notebook.component_drill.__main__:main"
        ]
    }
)
